# eXRC
[![eXRC Release](https://github.com/eXhumer/pyeXRC/actions/workflows/release.yml/badge.svg?branch=python3)][release-yml]

Reddit OAuth2 client to access Reddit resources via [OAuth2][reddit-oauth2], powered by [httpx][httpx] & [websocket-client][websocket-client]. 

## Package Installation Guide
### Requires
* Python 3.11+
* pip package manager

### Install from source
```console
pip install -e git+https://github.com/eXhumer/pyeXRC.git@python3#egg=exrc
```

### Install from PyPI
```console
pip install exrc
```

## Licensing
This project is licensed under OSI Approved [GNU AGPLv3 **ONLY**][project-license].

[release-yml]: https://github.com/eXhumer/pyeXRC/actions/workflows/release.yml "Release Action"
[reddit-oauth2]: <https://github.com/reddit-archive/reddit/wiki/OAuth2> "Reddit OAuth2 wiki"
[httpx]: <https://pypi.org/project/httpx/> "httpx"
[websocket-client]: <https://pypi.org/project/websocket-client/> "websocket-client"
[project-license]: <https://github.com/eXhumer/pyeXRC/blob/python3/COPYING.md> "Project License"
